==> 3.2.0.tar.gz: test/method_call_handler/select_account_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/select_account_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    const MethodChannel channel = MethodChannel(
      CommonTestData.methodChannelName,
    );

    group("Given selectAccount is called from the native side", () {
      const methodName = 'selectAccount';
      late MockMethodChannelMethodCallCache mockCache;
      group("When the incoming parameters are correct", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then the call is propagated to the cached delegate", () async {
          final AuthenticationPlatformOperation mockOperation =
              MockAuthenticationPlatformOperation();
          final MockAccountSelector mockSelector = MockAccountSelector();
          final AccountSelectionHandler mockHandler =
              MockAccountSelectionHandler();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(mockOperation);
          when(mockOperation.accountSelector).thenReturn(mockSelector);
          when(mockOperation.accountSelectionHandler).thenReturn(mockHandler);
          when(mockSelector.selectAccount(any, any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            SelectAccountTestData.correctArguments,
          );

          verifyInOrder([
            mockCache.getOperation(operationId),
            mockOperation.accountSelector,
            mockSelector.selectAccount(any, any),
          ]);
        });
      });

      group("When the incoming parameter are not correct", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then PlatformChannelException is thrown", () async {
          final AuthenticationPlatformOperation mockOperation =
              MockAuthenticationPlatformOperation();
          final MockAccountSelector mockSelector = MockAccountSelector();
          final AccountSelectionHandler mockHandler =
              MockAccountSelectionHandler();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(mockOperation);
          when(mockOperation.accountSelector).thenReturn(mockSelector);
          when(mockOperation.accountSelectionHandler).thenReturn(mockHandler);
          when(mockSelector.selectAccount(any, any)).thenReturn(null);

          try {
            await channel.invokeMockMethod(
              methodName,
              SelectAccountTestData.wrongArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(e.code, "error");
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verifyNever(mockCache.getOperation(operationId));
        });
      });

      group("When the operationId is missing", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(mockCache.getOperation(operationId)).thenThrow(
              PlatformChannelException(
                  error: PlatformChannelError.noOperationFoundError(
                      operationId: operationId)));

          try {
            await channel.invokeMockMethod(
              methodName,
              SelectAccountTestData.wrongIdArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(mockCache.getOperation(operationId));
        });
      });
    });
  });
}

==> 3.4.0.tar.gz: test/method_call_handler/select_account_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/select_account_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    late MethodChannel channel;
    late MockMethodChannelMethodCallCache cache;
    const methodName = 'selectAccount';

    setUp(() {
      cache = MockMethodChannelMethodCallCache();
      NevisMobileAuthenticationSdkIos.mock(
          MethodChannelMethodCallHandler.mock(cache));
      channel = const MethodChannel(
        CommonTestData.methodChannelName,
      );
    });

    tearDown(() {
      channel.setMockMethodCallHandler(null);
      resetMockitoState();
    });

    group("Given $methodName is called from the native side", () {
      group("When the incoming parameters are correct", () {
        test("Then the call is propagated to the cached delegate", () async {
          final operation = MockAuthenticationPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(cache.getOperation(operationId)).thenReturn(operation);

          await channel.invokeMockMethod(
            methodName,
            SelectAccountTestData.correctArguments,
          );

          verifyInOrder([
            cache.getOperation(operationId),
            operation.selectAccount(any),
          ]);
        });
      });

      group("When the incoming parameter are not correct", () {
        test("Then PlatformChannelException is thrown", () async {
          try {
            await channel.invokeMockMethod(
              methodName,
              SelectAccountTestData.wrongArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(e.code, "error");
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verifyNever(cache.getOperation(any));
        });
      });

      group("When the operationId is missing", () {
        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(cache.getOperation(operationId)).thenThrow(
            PlatformChannelException(
              error: PlatformChannelError.noOperationFoundError(
                operationId: operationId,
              ),
            ),
          );

          try {
            await channel.invokeMockMethod(
              methodName,
              SelectAccountTestData.wrongIdArguments,
            );
            fail('PlatformException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(cache.getOperation(operationId));
        });
      });
    });
  });
}
